summaryrefslogtreecommitdiffstats
path: root/amarok/src/engine
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:34:55 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:34:55 -0600
commitcfc8e6815b1ebe8f8c05168cfe98cb31d2e6f86c (patch)
tree8afd51bca5b43056b791166a25cacff08b4055b7 /amarok/src/engine
parentca249ab4c84ef5672ce82e80cf7f27197ad5b5d2 (diff)
downloadamarok-cfc8e6815b1ebe8f8c05168cfe98cb31d2e6f86c.tar.gz
amarok-cfc8e6815b1ebe8f8c05168cfe98cb31d2e6f86c.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'amarok/src/engine')
-rw-r--r--amarok/src/engine/akode/akode-engine.cpp2
-rw-r--r--amarok/src/engine/helix/helix-engine.cpp10
-rw-r--r--amarok/src/engine/helix/helix-sp/helix-include/common/include/hxmon.h16
-rw-r--r--amarok/src/engine/helix/helix-sp/helix-sp.cpp2
-rw-r--r--amarok/src/engine/helix/hxplayercontrol.cpp214
-rw-r--r--amarok/src/engine/helix/hxplayercontrol.h4
-rw-r--r--amarok/src/engine/nmm/HostList.cpp2
-rw-r--r--amarok/src/engine/xine/xine-engine.cpp10
-rw-r--r--amarok/src/engine/xine/xineconfigbase.ui4
-rw-r--r--amarok/src/engine/yauap/yauap-engine.cpp2
10 files changed, 133 insertions, 133 deletions
diff --git a/amarok/src/engine/akode/akode-engine.cpp b/amarok/src/engine/akode/akode-engine.cpp
index f2404012..26840589 100644
--- a/amarok/src/engine/akode/akode-engine.cpp
+++ b/amarok/src/engine/akode/akode-engine.cpp
@@ -180,7 +180,7 @@ AkodeEngine::event( TQEvent *e )
case 3002:
m_player->stop();
emit trackEnded();
- emit infoMessage( i18n("Unable to decode <i>%1</i>").tqarg( m_url.prettyURL()) );
+ emit infoMessage( i18n("Unable to decode <i>%1</i>").arg( m_url.prettyURL()) );
break;
default:
diff --git a/amarok/src/engine/helix/helix-engine.cpp b/amarok/src/engine/helix/helix-engine.cpp
index 7d778741..fb4dc695 100644
--- a/amarok/src/engine/helix/helix-engine.cpp
+++ b/amarok/src/engine/helix/helix-engine.cpp
@@ -126,7 +126,7 @@ void HelixEngine::notifyUser(unsigned long code, const char *moreinfo, const cha
{
TQString *err = HelixErrors::errorText(code);
if (err)
- emit statusText(i18n("Helix Core returned error: %1 %2 %3").tqarg(TQString(*err)).tqarg(TQString(moreinfo)).tqarg(TQString(moreinfourl)));
+ emit statusText(i18n("Helix Core returned error: %1 %2 %3").arg(TQString(*err)).arg(TQString(moreinfo)).arg(TQString(moreinfourl)));
else
emit statusText(i18n("Helix Core returned error: <unknown>"));
}
@@ -135,7 +135,7 @@ void HelixEngine::interruptUser(unsigned long code, const char *moreinfo, const
{
TQString *err = HelixErrors::errorText(code);
if (err)
- emit infoMessage(i18n("Helix Core returned error: %1 %1 %1").tqarg(TQString(*err)).tqarg(TQString(moreinfo)).tqarg(TQString(moreinfourl)));
+ emit infoMessage(i18n("Helix Core returned error: %1 %1 %1").arg(TQString(*err)).arg(TQString(moreinfo)).arg(TQString(moreinfourl)));
else
emit infoMessage(i18n("Helix Core returned error: <unknown>"));
@@ -146,13 +146,13 @@ void HelixEngine::interruptUser(unsigned long code, const char *moreinfo, const
void HelixEngine::onContacting(const char *host)
{
- emit statusText( i18n("Contacting: %1").tqarg( TQString(host) ) );
+ emit statusText( i18n("Contacting: %1").arg( TQString(host) ) );
}
void HelixEngine::onBuffering(int pcnt)
{
if (pcnt != 100) // let's not report that...
- emit statusText( i18n( "Buffering %1%" ).tqarg( pcnt ) );
+ emit statusText( i18n( "Buffering %1%" ).arg( pcnt ) );
}
@@ -289,7 +289,7 @@ HelixEngine::load( const KURL &url, bool isStream )
{
const TQString path = url.path();
const TQString ext = path.mid( path.findRev( '.' ) + 1 ).lower();
- emit statusText( i18n("No plugin found for the %1 format").tqarg(ext) );
+ emit statusText( i18n("No plugin found for the %1 format").arg(ext) );
return false;
}
diff --git a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxmon.h b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxmon.h
index 775d287c..e29fe874 100644
--- a/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxmon.h
+++ b/amarok/src/engine/helix/helix-sp/helix-include/common/include/hxmon.h
@@ -531,7 +531,7 @@ DECLARE_INTERFACE_(IHXRegistry, IUnknown)
* Returns the count of the number of Properties under the one
* whose name is specified in "pName".
*
- * pName - IN - name of the Property whose number of tqchildren is to be
+ * pName - IN - name of the Property whose number of children is to be
* retrieved
*/
STDMETHOD_(INT32, GetNumPropsByName) (THIS_
@@ -544,7 +544,7 @@ DECLARE_INTERFACE_(IHXRegistry, IUnknown)
* Returns the count of the number of Properties under the one
* whose unique id is specified in "ulId".
*
- * ulId - IN - unique id of the Property whose number of tqchildren is
+ * ulId - IN - unique id of the Property whose number of children is
* to be retrieved
*/
STDMETHOD_(INT32, GetNumPropsById) (THIS_
@@ -1594,7 +1594,7 @@ DECLARE_INTERFACE_(IHXRegistry2, IUnknown)
* Returns the count of the number of Properties under the one
* whose name is specified in "pName".
*
- * pName - IN - name of the Property whose number of tqchildren is to be
+ * pName - IN - name of the Property whose number of children is to be
* retrieved
*/
STDMETHOD_(INT32, GetNumPropsByName) (THIS_
@@ -1607,7 +1607,7 @@ DECLARE_INTERFACE_(IHXRegistry2, IUnknown)
* Returns the count of the number of Properties under the one
* whose unique id is specified in "ulId".
*
- * ulId - IN - unique id of the Property whose number of tqchildren is
+ * ulId - IN - unique id of the Property whose number of children is
* to be retrieved
*/
STDMETHOD_(INT32, GetNumPropsById) (THIS_
@@ -2089,10 +2089,10 @@ DECLARE_INTERFACE_(IHXRegistry2, IUnknown)
* Method:
* IHXRegistry2::GetChildIdListByName
* Purpose:
- * Get a array which enumerates all of the tqchildren under a
+ * Get a array which enumerates all of the children under a
* property by id.
*
- * pName - IN - name of the Property whose tqchildren are to be enumerated.
+ * pName - IN - name of the Property whose children are to be enumerated.
* pValues - OUT - array of unique Property id's.
* ulCount - OUT - size of the returned pValues array.
*
@@ -2108,10 +2108,10 @@ DECLARE_INTERFACE_(IHXRegistry2, IUnknown)
* Method:
* IHXRegistry2::GetChildIdListById
* Purpose:
- * Get a array which enumerates all of the tqchildren under a
+ * Get a array which enumerates all of the children under a
* property by id.
*
- * ulId - IN - unique id of the Property whose tqchildren are to be enumerated.
+ * ulId - IN - unique id of the Property whose children are to be enumerated.
* pValues - OUT - array of unique Property id's.
* ulCount - OUT - size of the returned pValues array.
*
diff --git a/amarok/src/engine/helix/helix-sp/helix-sp.cpp b/amarok/src/engine/helix/helix-sp/helix-sp.cpp
index 4cb58bb7..41c84a1d 100644
--- a/amarok/src/engine/helix/helix-sp/helix-sp.cpp
+++ b/amarok/src/engine/helix/helix-sp/helix-sp.cpp
@@ -835,7 +835,7 @@ HelixSimplePlayer::~HelixSimplePlayer()
{
tearDown();
- // only now tqinvalidate the device, not whenever we teardown
+ // only now invalidate the device, not whenever we teardown
delete [] m_device;
}
diff --git a/amarok/src/engine/helix/hxplayercontrol.cpp b/amarok/src/engine/helix/hxplayercontrol.cpp
index fabc8a0d..8cb26939 100644
--- a/amarok/src/engine/helix/hxplayercontrol.cpp
+++ b/amarok/src/engine/helix/hxplayercontrol.cpp
@@ -69,7 +69,7 @@ PlayerControl::PlayerControl() : m_eq_enabled(false), m_preamp(0), m_err(0), iam
m_inited(false), m_api( HelixSimplePlayer::OSS ), m_device(0), mimehead(0), mimelistlen(0),
m_numPlugins(0), m_pluginInfo(0)
{
- memset(m_tqchildren, 0, sizeof(m_tqchildren));
+ memset(m_children, 0, sizeof(m_children));
}
PlayerControl::~PlayerControl()
@@ -100,7 +100,7 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
return;
}
- memset(&m_tqchildren, 0, numPlayers * sizeof(struct playerChildren));
+ memset(&m_children, 0, numPlayers * sizeof(struct playerChildren));
m_inited = false;
@@ -121,30 +121,30 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
{
if (pmapped)
{
- m_tqchildren[i].current_time = &(pmapped[i].current_time);
- m_tqchildren[i].duration = &(pmapped[i].duration);
- m_tqchildren[i].md = &(pmapped[i].md);
+ m_children[i].current_time = &(pmapped[i].current_time);
+ m_children[i].duration = &(pmapped[i].duration);
+ m_children[i].md = &(pmapped[i].md);
- m_tqchildren[i].m_current = &(pmapped[i].m_current);
- m_tqchildren[i].m_consumed = &(pmapped[i].m_consumed);
- //m_tqchildren[i].q = pmapped[i].q;
+ m_children[i].m_current = &(pmapped[i].m_current);
+ m_children[i].m_consumed = &(pmapped[i].m_consumed);
+ //m_children[i].q = pmapped[i].q;
//for (int j=0; j<NUM_SCOPEBUFS; j++)
//{
- // m_tqchildren[i].q[j].allocd = false;
- // m_tqchildren[i].q[j].buf = pmapped[i].b[j];
+ // m_children[i].q[j].allocd = false;
+ // m_children[i].q[j].buf = pmapped[i].b[j];
//}
}
- err = pipe(m_tqchildren[i].m_pipeA);
- err |= pipe(m_tqchildren[i].m_pipeB);
+ err = pipe(m_children[i].m_pipeA);
+ err |= pipe(m_children[i].m_pipeB);
if ( !err && (iamparent = fork()) )
{
// parent
print2stderr("%%%%%% parent initializes player %d\n", i);
// parent's m_pid remains 0
- m_tqchildren[i].m_pid = iamparent;
- close(m_tqchildren[i].m_pipeA[1]); // parent uses A for reading
- close(m_tqchildren[i].m_pipeB[0]); // and B for writing
+ m_children[i].m_pid = iamparent;
+ close(m_children[i].m_pipeA[1]); // parent uses A for reading
+ close(m_children[i].m_pipeB[0]); // and B for writing
}
else if (!err)
{
@@ -153,17 +153,17 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
cerr << "%%%%%% child initializes as player " << i << endl;;
m_index = i; // child's index is saved
- close(m_tqchildren[i].m_pipeA[0]); // child uses A for writing
- close(m_tqchildren[i].m_pipeB[1]); // and B for reading
+ close(m_children[i].m_pipeA[0]); // child uses A for writing
+ close(m_children[i].m_pipeB[1]); // and B for reading
break;
}
}
- if (!iamparent) // tqchildren stay here, parents return
+ if (!iamparent) // children stay here, parents return
{
- int rfd = m_tqchildren[m_index].m_pipeB[0];
- int wfd = m_tqchildren[m_index].m_pipeA[1];
+ int rfd = m_children[m_index].m_pipeB[0];
+ int wfd = m_children[m_index].m_pipeA[1];
int n;
struct timeval timeout;
HSPPlayerControlled *player = 0;
@@ -237,7 +237,7 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
if (m_inited)
{
if (pmapped)
- *m_tqchildren[m_index].current_time = 0;
+ *m_children[m_index].current_time = 0;
if (sz == sizeof(unsigned long) + 1)
{
@@ -397,7 +397,7 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
{
player->clearScopeQ(0);
if (pmapped)
- *m_tqchildren[m_index].m_consumed = *m_tqchildren[m_index].m_current = 0;
+ *m_children[m_index].m_consumed = *m_children[m_index].m_current = 0;
}
break;
case TEARDOWN:
@@ -437,36 +437,36 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
playing = false;
if (pmapped)
{
- *m_tqchildren[m_index].current_time = 0;
- *m_tqchildren[m_index].duration = 0;
+ *m_children[m_index].current_time = 0;
+ *m_children[m_index].duration = 0;
}
}
if (pmapped)
{
- *m_tqchildren[m_index].current_time = player->where(0);
- *m_tqchildren[m_index].duration = player->duration(0);
+ *m_children[m_index].current_time = player->where(0);
+ *m_children[m_index].duration = player->duration(0);
HelixSimplePlayer::metaData *md = player->getMetaData(0);
if (md)
- memcpy((void *) m_tqchildren[m_index].md, (void *) md, sizeof(HelixSimplePlayer::metaData));
+ memcpy((void *) m_children[m_index].md, (void *) md, sizeof(HelixSimplePlayer::metaData));
struct DelayQueue *item;
//int j;
while ((item = player->getScopeBuf(0)))
{
- //j = (*m_tqchildren[m_index].m_current + 1) % NUM_SCOPEBUFS;
+ //j = (*m_children[m_index].m_current + 1) % NUM_SCOPEBUFS;
//cerr << "player:" << m_index << " j=" << j << " time=" << item->time << " etime=" << item->etime << " len=" << item->len << endl;
- //m_tqchildren[m_index].q[j].len = item->len;
- //m_tqchildren[m_index].q[j].time = item->time;
- //m_tqchildren[m_index].q[j].etime = item->etime;
- //m_tqchildren[m_index].q[j].nchan = item->nchan;
- //m_tqchildren[m_index].q[j].bps = item->bps;
- //m_tqchildren[m_index].q[j].tps = item->tps;
- //m_tqchildren[m_index].q[j].spb = item->spb;
- //memcpy((void *)m_tqchildren[m_index].q[j].buf, (void *) item->buf, item->len );
- //*m_tqchildren[m_index].m_current = j;
+ //m_children[m_index].q[j].len = item->len;
+ //m_children[m_index].q[j].time = item->time;
+ //m_children[m_index].q[j].etime = item->etime;
+ //m_children[m_index].q[j].nchan = item->nchan;
+ //m_children[m_index].q[j].bps = item->bps;
+ //m_children[m_index].q[j].tps = item->tps;
+ //m_children[m_index].q[j].spb = item->spb;
+ //memcpy((void *)m_children[m_index].q[j].buf, (void *) item->buf, item->len );
+ //*m_children[m_index].m_current = j;
//cerr << "player:" << m_index << " time=" << item->time << " etime=" << item->etime << endl;
sendscopebuf(wfd, item);
delete item;
@@ -488,15 +488,15 @@ void PlayerControl::init(const char *corelibpath, const char *pluginslibpath, co
sendsetdevice();
sendinit();
- // wait for ready from tqchildren
+ // wait for ready from children
while (!done && !dead)
{
dispatch();
done = true;
for (i=0; i<numPlayers; i++)
{
- done &= m_tqchildren[i].isready;
- dead |= m_tqchildren[i].isdead;
+ done &= m_children[i].isready;
+ dead |= m_children[i].isdead;
}
}
@@ -540,12 +540,12 @@ void PlayerControl::tearDown()
{
if (m_inited)
{
- sendteardown(m_tqchildren[i].m_pipeB[1]);
- close(m_tqchildren[i].m_pipeB[1]);
- close(m_tqchildren[i].m_pipeA[0]);
- cerr << "About to waitpid for pid " << m_tqchildren[i].m_pid << endl;
- kill(m_tqchildren[i].m_pid, SIGTERM);
- waitpid(m_tqchildren[i].m_pid, &tmp, 0);
+ sendteardown(m_children[i].m_pipeB[1]);
+ close(m_children[i].m_pipeB[1]);
+ close(m_children[i].m_pipeA[0]);
+ cerr << "About to waitpid for pid " << m_children[i].m_pid << endl;
+ kill(m_children[i].m_pid, SIGTERM);
+ waitpid(m_children[i].m_pid, &tmp, 0);
}
}
}
@@ -553,16 +553,16 @@ void PlayerControl::tearDown()
void PlayerControl::start(int playerIndex, bool fadein, unsigned long fadetime)
{
- m_tqchildren[playerIndex].isplaying = true;
+ m_children[playerIndex].isplaying = true;
if (pmapped)
- *m_tqchildren[playerIndex].m_consumed = *m_tqchildren[playerIndex].m_current = 0;
- sendstart(m_tqchildren[playerIndex].m_pipeB[1], fadein, fadetime);
+ *m_children[playerIndex].m_consumed = *m_children[playerIndex].m_current = 0;
+ sendstart(m_children[playerIndex].m_pipeB[1], fadein, fadetime);
}
int PlayerControl::setURL(const char *url, int playerIndex, bool islocal)
{
- m_tqchildren[playerIndex].islocal = islocal;
- if (sendsetURL(m_tqchildren[playerIndex].m_pipeB[1], url, islocal))
+ m_children[playerIndex].islocal = islocal;
+ if (sendsetURL(m_children[playerIndex].m_pipeB[1], url, islocal))
return 0;
return -1;
@@ -570,7 +570,7 @@ int PlayerControl::setURL(const char *url, int playerIndex, bool islocal)
bool PlayerControl::done(int playerIndex)
{
- return (!m_tqchildren[playerIndex].isplaying);
+ return (!m_children[playerIndex].isplaying);
}
void PlayerControl::stop(int playerIndex)
@@ -582,30 +582,30 @@ void PlayerControl::stop(int playerIndex)
}
else
{
- m_tqchildren[playerIndex].isplaying = false;
- sendstop(m_tqchildren[playerIndex].m_pipeB[1]);
+ m_children[playerIndex].isplaying = false;
+ sendstop(m_children[playerIndex].m_pipeB[1]);
}
}
void PlayerControl::pause(int playerIndex)
{
- sendpause(m_tqchildren[playerIndex].m_pipeB[1]);
+ sendpause(m_children[playerIndex].m_pipeB[1]);
}
void PlayerControl::resume(int playerIndex)
{
- sendresume(m_tqchildren[playerIndex].m_pipeB[1]);
+ sendresume(m_children[playerIndex].m_pipeB[1]);
}
void PlayerControl::seek(unsigned long pos, int playerIndex)
{
- sendmessage(m_tqchildren[playerIndex].m_pipeB[1], SEEK, (unsigned char *) &pos, sizeof(unsigned long));
+ sendmessage(m_children[playerIndex].m_pipeB[1], SEEK, (unsigned char *) &pos, sizeof(unsigned long));
}
unsigned long PlayerControl::where(int playerIndex) const
{
if (pmapped)
- return *m_tqchildren[playerIndex].current_time;
+ return *m_children[playerIndex].current_time;
else
return 0;
}
@@ -613,7 +613,7 @@ unsigned long PlayerControl::where(int playerIndex) const
unsigned long PlayerControl::duration(int playerIndex) const
{
if (pmapped)
- return *m_tqchildren[playerIndex].duration;
+ return *m_children[playerIndex].duration;
else
return 0;
}
@@ -627,7 +627,7 @@ void PlayerControl::setVolume(unsigned long vol)
{
m_volume = vol;
for (int i = 0; i < nNumPlayers; i++)
- sendsetvolume(m_tqchildren[i].m_pipeB[1], vol);
+ sendsetvolume(m_children[i].m_pipeB[1], vol);
}
void PlayerControl::dispatch()
@@ -647,8 +647,8 @@ void PlayerControl::dispatch()
for (i=0; i<nNumPlayers; i++)
{
- rfd = m_tqchildren[i].m_pipeA[0];
- wfd = m_tqchildren[i].m_pipeB[1];
+ rfd = m_children[i].m_pipeA[0];
+ wfd = m_children[i].m_pipeB[1];
FD_SET(rfd, &rdset);
FD_SET(wfd, &wrset); // really should check to see if we can write, but not gonna
if (rfd > n)
@@ -661,8 +661,8 @@ void PlayerControl::dispatch()
ntot = select(n + 1, &rdset, 0, 0, &timeout);
for (i=0; ntot && i < nNumPlayers; i++)
{
- rfd = m_tqchildren[i].m_pipeA[0];
- wfd = m_tqchildren[i].m_pipeB[1];
+ rfd = m_children[i].m_pipeA[0];
+ wfd = m_children[i].m_pipeB[1];
if ( FD_ISSET(rfd, &rdset) )
{
msgid m;
@@ -675,14 +675,14 @@ void PlayerControl::dispatch()
{
case READY:
print2stderr("CHILD %d is READY\n", i);
- m_tqchildren[i].isready = true;;
+ m_children[i].isready = true;;
break;
case DONE:
print2stderr("CHILD %d is DONE\n", i);
if (!sz)
{
- m_tqchildren[i].isplaying = false;
+ m_children[i].isplaying = false;
clearScopeQ(i);
play_finished(i);
}
@@ -852,7 +852,7 @@ void PlayerControl::dispatch()
}
else
{
- m_tqchildren[i].isdead = true;
+ m_children[i].isdead = true;
return; // should never happen
}
}
@@ -860,16 +860,16 @@ void PlayerControl::dispatch()
for (i=0; pmapped && i<nNumPlayers; i++)
{
- while (*m_tqchildren[i].m_consumed != *m_tqchildren[i].m_current)
+ while (*m_children[i].m_consumed != *m_children[i].m_current)
{
- addScopeBuf(&m_tqchildren[i].q[*m_tqchildren[i].m_consumed], i);
+ addScopeBuf(&m_children[i].q[*m_children[i].m_consumed], i);
- //cerr << "j=" << *m_tqchildren[i].m_consumed <<
- // " time=" << m_tqchildren[i].q[*m_tqchildren[i].m_consumed].time <<
- // " etime=" << m_tqchildren[i].q[*m_tqchildren[i].m_consumed].etime <<
- // " len=" << m_tqchildren[i].q[*m_tqchildren[i].m_consumed].len << endl;
+ //cerr << "j=" << *m_children[i].m_consumed <<
+ // " time=" << m_children[i].q[*m_children[i].m_consumed].time <<
+ // " etime=" << m_children[i].q[*m_children[i].m_consumed].etime <<
+ // " len=" << m_children[i].q[*m_children[i].m_consumed].len << endl;
- *m_tqchildren[i].m_consumed = (*m_tqchildren[i].m_consumed + 1) % NUM_SCOPEBUFS;
+ *m_children[i].m_consumed = (*m_children[i].m_consumed + 1) % NUM_SCOPEBUFS;
}
}
}
@@ -881,37 +881,37 @@ void PlayerControl::cleanUpStream(int playerIndex)
bool PlayerControl::isPlaying(int playerIndex) const
{
- return m_tqchildren[playerIndex].isplaying;
+ return m_children[playerIndex].isplaying;
}
bool PlayerControl::isLocal(int playerIndex) const
{
- return m_tqchildren[playerIndex].islocal;
+ return m_children[playerIndex].islocal;
}
void PlayerControl::setFadeout(bool fadeout, unsigned long fadelength, int playerIndex)
{
- sendsetfade(m_tqchildren[playerIndex].m_pipeB[1], fadeout, fadelength);
+ sendsetfade(m_children[playerIndex].m_pipeB[1], fadeout, fadelength);
}
void PlayerControl::addScopeBuf(struct DelayQueue *item, int playerIndex)
{
if (playerIndex >=0 && playerIndex < nNumPlayers)
{
- if (m_tqchildren[playerIndex].scopebuftail)
+ if (m_children[playerIndex].scopebuftail)
{
item->fwd = 0;
- m_tqchildren[playerIndex].scopebuftail->fwd = item;
- m_tqchildren[playerIndex].scopebuftail = item;
- m_tqchildren[playerIndex].scopecount++;
+ m_children[playerIndex].scopebuftail->fwd = item;
+ m_children[playerIndex].scopebuftail = item;
+ m_children[playerIndex].scopecount++;
}
else
{
item->fwd = 0;
- m_tqchildren[playerIndex].scopebufhead = item;
- m_tqchildren[playerIndex].scopebuftail = item;
- m_tqchildren[playerIndex].scopecount = 1;
+ m_children[playerIndex].scopebufhead = item;
+ m_children[playerIndex].scopebuftail = item;
+ m_children[playerIndex].scopecount = 1;
}
}
}
@@ -920,14 +920,14 @@ DelayQueue *PlayerControl::getScopeBuf(int playerIndex)
{
if (playerIndex >=0 && playerIndex < nNumPlayers)
{
- struct DelayQueue *item = m_tqchildren[playerIndex].scopebufhead;
+ struct DelayQueue *item = m_children[playerIndex].scopebufhead;
if (item)
{
- m_tqchildren[playerIndex].scopebufhead = item->fwd;
- m_tqchildren[playerIndex].scopecount--;
- if (!m_tqchildren[playerIndex].scopebufhead)
- m_tqchildren[playerIndex].scopebuftail = 0;
+ m_children[playerIndex].scopebufhead = item->fwd;
+ m_children[playerIndex].scopecount--;
+ if (!m_children[playerIndex].scopebufhead)
+ m_children[playerIndex].scopebuftail = 0;
}
return item;
}
@@ -937,15 +937,15 @@ DelayQueue *PlayerControl::getScopeBuf(int playerIndex)
int PlayerControl::getScopeCount(int playerIndex)
{
- return (playerIndex >= 0 && playerIndex < nNumPlayers ? m_tqchildren[playerIndex].scopecount : 0);
+ return (playerIndex >= 0 && playerIndex < nNumPlayers ? m_children[playerIndex].scopecount : 0);
}
int PlayerControl::peekScopeTime(unsigned long &t, int playerIndex)
{
if (playerIndex >=0 && playerIndex < nNumPlayers)
{
- if (m_tqchildren[playerIndex].scopebufhead)
- t = m_tqchildren[playerIndex].scopebufhead->time;
+ if (m_children[playerIndex].scopebufhead)
+ t = m_children[playerIndex].scopebufhead->time;
else
return -1;
return 0;
@@ -962,7 +962,7 @@ void PlayerControl::clearScopeQ(int playerIndex)
}
else
{
- sendscopeclear(m_tqchildren[playerIndex].m_pipeB[1]);
+ sendscopeclear(m_children[playerIndex].m_pipeB[1]);
struct DelayQueue *item;
while ((item = getScopeBuf(playerIndex)))
if (item->allocd)
@@ -976,7 +976,7 @@ void PlayerControl::enableEQ(bool enabled)
unsigned char c = (char) enabled;
for (i=0; i<nNumPlayers; i++)
- sendmessage(m_tqchildren[i].m_pipeB[1], ENABLEEQ, (unsigned char *) &c, 1);
+ sendmessage(m_children[i].m_pipeB[1], ENABLEEQ, (unsigned char *) &c, 1);
m_eq_enabled = enabled;
}
@@ -1021,7 +1021,7 @@ int PlayerControl::getMimeListLen() const
HelixSimplePlayer::metaData *PlayerControl::getMetaData(int playerIndex )
{
- return m_tqchildren[playerIndex].md;
+ return m_children[playerIndex].md;
}
bool PlayerControl::sendsetoutputsink()
@@ -1031,7 +1031,7 @@ bool PlayerControl::sendsetoutputsink()
bool ok = false;
for (i=0; i<nNumPlayers; i++)
- ok |= sendmessage(m_tqchildren[i].m_pipeB[1], OUTPUTSINK, (unsigned char *) &c, 1);
+ ok |= sendmessage(m_children[i].m_pipeB[1], OUTPUTSINK, (unsigned char *) &c, 1);
return ok;
}
@@ -1045,7 +1045,7 @@ bool PlayerControl::sendsetdevice()
bool ok = false;
for (i=0; i<nNumPlayers; i++)
- ok |= sendmessage(m_tqchildren[i].m_pipeB[1], DEVICE, (unsigned char *) m_device, len + 1);
+ ok |= sendmessage(m_children[i].m_pipeB[1], DEVICE, (unsigned char *) m_device, len + 1);
return ok;
}
@@ -1056,7 +1056,7 @@ bool PlayerControl::sendinit()
bool ok = false;
for (i=0; i<nNumPlayers; i++)
- ok |= sendrequest(m_tqchildren[i].m_pipeB[1], INIT);
+ ok |= sendrequest(m_children[i].m_pipeB[1], INIT);
return ok;
}
@@ -1077,12 +1077,12 @@ bool PlayerControl::sendupdateeqgains()
memcpy((void *)&buf[ sizeof(m_preamp) + (i+1) * sizeof(int) ], (void *) &bandGain, sizeof(int));
}
for ( i = 0; i < (uint) nNumPlayers; i++ )
- ok |= sendmessage(m_tqchildren[i].m_pipeB[1], UPDATEETQGAINS, buf, sizeof(m_preamp) + (m_equalizerGains.size()+1) * sizeof(int));
+ ok |= sendmessage(m_children[i].m_pipeB[1], UPDATEETQGAINS, buf, sizeof(m_preamp) + (m_equalizerGains.size()+1) * sizeof(int));
return ok;
}
-// tqchildren send this!
+// children send this!
bool PlayerControl::sendnotifyuser(unsigned long code, const char *moreinfo, const char *moreinfourl)
{
int len1 = strlen(moreinfo), len2 = strlen(moreinfourl), len;
@@ -1095,10 +1095,10 @@ bool PlayerControl::sendnotifyuser(unsigned long code, const char *moreinfo, con
memcpy( (void *) &buf[ len ], (void *) moreinfourl, len2 + 1);
len += len2 + 1;
- return (sendmessage(m_tqchildren[m_index].m_pipeA[1], NOTIFYUSER, buf, len));
+ return (sendmessage(m_children[m_index].m_pipeA[1], NOTIFYUSER, buf, len));
}
-// tqchildren send this!
+// children send this!
bool PlayerControl::sendinterruptuser(unsigned long code, const char *moreinfo, const char *moreinfourl)
{
int len1 = strlen(moreinfo), len2 = strlen(moreinfourl), len;
@@ -1111,21 +1111,21 @@ bool PlayerControl::sendinterruptuser(unsigned long code, const char *moreinfo,
memcpy( (void *) &buf[ len ], (void *) moreinfourl, len2 + 1);
len += len2 + 1;
- return (sendmessage(m_tqchildren[m_index].m_pipeA[1], INTERRUPTUSER, buf, len));
+ return (sendmessage(m_children[m_index].m_pipeA[1], INTERRUPTUSER, buf, len));
}
-// tqchildren send this!
+// children send this!
bool PlayerControl::sendcontacting(const char *host)
{
int len = strlen(host);
- return (sendmessage(m_tqchildren[m_index].m_pipeA[1], CONTACTING, (unsigned char *) host, len + 1));
+ return (sendmessage(m_children[m_index].m_pipeA[1], CONTACTING, (unsigned char *) host, len + 1));
}
-// tqchildren send this!
+// children send this!
bool PlayerControl::sendbuffering(int percentage)
{
- return (sendmessage(m_tqchildren[m_index].m_pipeA[1], BUFFERING, (unsigned char *) &percentage, sizeof(unsigned long)));
+ return (sendmessage(m_children[m_index].m_pipeA[1], BUFFERING, (unsigned char *) &percentage, sizeof(unsigned long)));
}
diff --git a/amarok/src/engine/nmm/HostList.cpp b/amarok/src/engine/nmm/HostList.cpp
index 5c7e4d08..623f2852 100644
--- a/amarok/src/engine/nmm/HostList.cpp
+++ b/amarok/src/engine/nmm/HostList.cpp
@@ -68,7 +68,7 @@ void HostList::notifyHostError( TQString hostname, int error)
{
host->setText( HostListItem::Hostname, hostname );
host->setStatus( error );
- host->tqrepaint();
+ host->repaint();
return;
}
++it;
diff --git a/amarok/src/engine/xine/xine-engine.cpp b/amarok/src/engine/xine/xine-engine.cpp
index 581923be..48353ac3 100644
--- a/amarok/src/engine/xine/xine-engine.cpp
+++ b/amarok/src/engine/xine/xine-engine.cpp
@@ -801,7 +801,7 @@ XineEngine::customEvent( TQCustomEvent *e )
break;
case 3001:
- emit infoMessage( (*message).tqarg( m_url.prettyURL() ) );
+ emit infoMessage( (*message).arg( m_url.prettyURL() ) );
delete message;
break;
@@ -818,7 +818,7 @@ XineEngine::customEvent( TQCustomEvent *e )
} break;
case 3004:
- emit statusText( i18n("Redirecting to: ").tqarg( *message ) );
+ emit statusText( i18n("Redirecting to: ").arg( *message ) );
load( KURL( *message ), false );
play();
delete message;
@@ -923,8 +923,8 @@ XineEngine::XineEventListener( void *p, const xine_event_t* xineEvent )
TQString
msg = "%1 %2%";
- msg = msg.tqarg( TQString::fromUtf8( pd->description ) )
- .tqarg( KGlobal::locale()->formatNumber( pd->percent, 0 ) );
+ msg = msg.arg( TQString::fromUtf8( pd->description ) )
+ .arg( KGlobal::locale()->formatNumber( pd->percent, 0 ) );
TQCustomEvent *e = new TQCustomEvent( 3002 );
e->setData( new TQString( msg ) );
@@ -1102,7 +1102,7 @@ bool XineEngine::metaDataForUrl(const KURL &url, Engine::SimpleMetaBundle &b)
if( b.tracknr.isEmpty() )
b.tracknr = url.filename();
} else {
- b.title = TQString(i18n("Track %1")).tqarg(url.filename());
+ b.title = TQString(i18n("Track %1")).arg(url.filename());
b.album = i18n("AudioCD");
}
}
diff --git a/amarok/src/engine/xine/xineconfigbase.ui b/amarok/src/engine/xine/xineconfigbase.ui
index d7826100..7e55162a 100644
--- a/amarok/src/engine/xine/xineconfigbase.ui
+++ b/amarok/src/engine/xine/xineconfigbase.ui
@@ -68,7 +68,7 @@
<property name="text">
<string></string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignCenter</set>
</property>
</widget>
@@ -129,7 +129,7 @@
<property name="text">
<string>Sound device may be modified after the output plugin has been changed to ALSA or OSS.</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
diff --git a/amarok/src/engine/yauap/yauap-engine.cpp b/amarok/src/engine/yauap/yauap-engine.cpp
index e9fef143..b3e8f0cd 100644
--- a/amarok/src/engine/yauap/yauap-engine.cpp
+++ b/amarok/src/engine/yauap/yauap-engine.cpp
@@ -646,7 +646,7 @@ yauapEngine::getAudioCDContents(const TQString &device, KURL::List &urls)
KURL url = TQString(TQString("cdda://").append( strtok_r(reply_ptr,"=",&saveptr)));
urls << url;
debug() << url << endl;
- b.title = TQString( i18n( "Track %1" ) ).tqarg( i+1 );
+ b.title = TQString( i18n( "Track %1" ) ).arg( i+1 );
b.length = strtok_r(NULL,"=",&saveptr);
b.album = "AudioCD";
b.tracknr = i+1;
diff --git a/amarok/src/engine/helix/hxplayercontrol.h b/amarok/src/engine/helix/hxplayercontrol.h
index 37b0a121..8ccdd445 100644
--- a/amarok/src/engine/helix/hxplayercontrol.h
+++ b/amarok/src/engine/helix/hxplayercontrol.h
@@ -87,7 +87,7 @@ public:
virtual void onContacting(const char */*host*/) {}
virtual void onBuffering(int /*percentage*/) {}
// tqchildren send functions
bool sendnotifyuser(unsigned long code, const char *moreinfo, const char *moreinfourl);
bool sendinterruptuser(unsigned long code, const char *moreinfo, const char *moreinfourl);
bool sendcontacting(const char *host);
@@ -129,7 +129,7 @@ private:
DelayQueue *q;
int *m_current;
int *m_consumed;
- } m_tqchildren[2];
+ } m_children[2];
unsigned long m_volume;
@@ -87,7 +87,7 @@ public:
virtual void onContacting(const char */*host*/) {}
virtual void onBuffering(int /*percentage*/) {}
- // tqchildren send functions
+ // children send functions
bool sendnotifyuser(unsigned long code, const char *moreinfo, const char *moreinfourl);
bool sendinterruptuser(unsigned long code, const char *moreinfo, const char *moreinfourl);